==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectWhileloop.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectwhileloop_h
#define objectwhileloop_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_whileloop {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  p_expression _while;
  int _while_isdefault : 1;
  gpointer _whileblock;
  int _whileblock_isdefault : 1;
  char* _name;
  int _name_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectExpression.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_whileloop_getuid (p_whileloop mywhileloop);
win32_interface gboolean adms_whileloop_cmp (p_whileloop mywhileloop,p_whileloop refwhileloop);
win32_interface p_whileloop adms_whileloop_new_1 (p_module mymodule,p_expression mywhile,gpointer mywhileblock);
#define adms_whileloop_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_whileloop_free(item)\
{\
  free(item->_name);\
  free(item);\
}
win32_interface p_adms adms_whileloop_new_impl (p_adms arguments[]);
win32_interface p_whileloop adms_whileloop_impl (void* member);
#define adms_whileloop(member) ((p_whileloop) (member))
#define adms_whileloop_new adms_whileloop_new_1
#define adms_whileloop_isdefault_module(whileloop) (adms_whileloop(whileloop)->_module_isdefault)
#define adms_whileloop_valueof_module(whileloop) (adms_whileloop(whileloop)->_module)
#define adms_whileloop_isdefault_while(whileloop) (adms_whileloop(whileloop)->_while_isdefault)
#define adms_whileloop_valueof_while(whileloop) (adms_whileloop(whileloop)->_while)
#define adms_whileloop_isdefault_whileblock(whileloop) (adms_whileloop(whileloop)->_whileblock_isdefault)
#define adms_whileloop_valueof_whileblock(whileloop) (adms_whileloop(whileloop)->_whileblock)
#define adms_whileloop_isdefault_name(whileloop) (adms_whileloop(whileloop)->_name_isdefault)
#define adms_whileloop_valueof_name(whileloop) (adms_whileloop(whileloop)->_name)
#define adms_whileloop_valueof_math(whileloop) ((p_math)whileloop)
#define adms_whileloop_valueof_adms(whileloop) ((p_adms)whileloop)
#define adms_whileloop_valueto_module(a,b) ((p_whileloop)a)->_module=(b)
win32_interface void adms_whileloop_valueto_module_impl (p_whileloop mywhileloop,p_module _module);
#define adms_whileloop_valueto_while(a,b) ((p_whileloop)a)->_while=(b)
win32_interface void adms_whileloop_valueto_while_impl (p_whileloop mywhileloop,p_expression _while);
#define adms_whileloop_valueto_whileblock(a,b) ((p_whileloop)a)->_whileblock=(b)
win32_interface void adms_whileloop_valueto_whileblock_impl (p_whileloop mywhileloop,gpointer _whileblock);
#define adms_whileloop_valueto_name(a,b) ((p_whileloop)a)->_name=(b)
win32_interface void adms_whileloop_valueto_name_impl (p_whileloop mywhileloop,char* _name);
#endif /* objectwhileloop_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectWhileloop.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectwhileloop_h
#define objectwhileloop_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_whileloop {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  p_expression _while;
  int _while_isdefault : 1;
  p_adms _whileblock;
  int _whileblock_isdefault : 1;
  p_quark _name;
  int _name_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectExpression.h>
#include <admsObject/objectQuark.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_whileloop_uid (p_whileloop mywhileloop);
win32_interface int adms_whileloop_cmp (p_whileloop mywhileloop,p_whileloop refwhileloop);
win32_interface p_whileloop adms_whileloop_new(p_module mymodule,p_expression mywhile,p_adms mywhileblock);
win32_interface p_adms adms_whileloop_new_impl (p_adms arguments[]);
#define adms_whileloop(member) ((p_whileloop) (member))
#define adms_whileloop_isdefault_module(whileloop) (adms_whileloop(whileloop)->_module_isdefault)
#define adms_whileloop_valueof_module(whileloop) (adms_whileloop(whileloop)->_module)
#define adms_whileloop_isdefault_while(whileloop) (adms_whileloop(whileloop)->_while_isdefault)
#define adms_whileloop_valueof_while(whileloop) (adms_whileloop(whileloop)->_while)
#define adms_whileloop_isdefault_whileblock(whileloop) (adms_whileloop(whileloop)->_whileblock_isdefault)
#define adms_whileloop_valueof_whileblock(whileloop) (adms_whileloop(whileloop)->_whileblock)
#define adms_whileloop_isdefault_name(whileloop) (adms_whileloop(whileloop)->_name_isdefault)
#define adms_whileloop_valueof_name(whileloop) (adms_whileloop(whileloop)->_name)
#define adms_whileloop_valueof_math(whileloop) ((p_math)whileloop)
#define adms_whileloop_valueof_adms(whileloop) ((p_adms)whileloop)
win32_interface inline void adms_whileloop_valueto_module (p_whileloop mywhileloop,p_module _module);
win32_interface inline void adms_whileloop_valueto_while (p_whileloop mywhileloop,p_expression _while);
win32_interface inline void adms_whileloop_valueto_whileblock (p_whileloop mywhileloop,p_adms _whileblock);
win32_interface inline void adms_whileloop_valueto_name (p_whileloop mywhileloop,p_quark _name);
win32_interface inline void adms_whileloop_free(p_whileloop mywhileloop);
#endif /* objectwhileloop_h */
